' ******************************************************************************
' *
' *  MBOXCMD - geschrieben in / written in FreeBASIC
' *
' *  Zeigt eine MessageBox auf der Kommandozeile an und liefert das Ergebnis /
' *  Shows a MessageBox from command line and returns the result
' *
' *  VERSION: 1.0, 10.12.2014, Tobias Jacobi
' *
' *
' *  HAFTUNGSAUSSCHLUSS
' *
' *  Dieser Quellcode wird kostenlos fr jegliche Verwendung zur Verfgung
' *  gestellt, aber ohne irgendeine Garantie oder Haftung. Sie knnen ihn
' *  auf eigene Gefahr verwenden oder verndern.
' *
' *  DISCLAIMER
' *
' *  This source code is provided free for all purposes, but without any
' *  warranty. Use or change it at your own risk.
' *
' *
' *  Ntzliche Informationen und Software zu FreeBasic finden Sie hier /
' *  You can find some useful informations and software around FreeBasic here:
' *
' *  http://www.freebasic.net/
' *  http://www.freebasic-portal.de/
' *
' ******************************************************************************

' Notwendige Sourcen einbinden
#Include "windows.bi"

' Funktionen und Prozeduren deklarieren
Declare Sub MyHelpText()
Declare Function MyReplace(ByVal PV_Original As String, _
                           ByVal PV_Displaced As String, _
                           ByVal PV_Replacement As String) As String

' Globale Variablen und Konstanten deklarieren und ggf. initialisieren
Const GC_ValidStyleMask As Integer = 4983, _
      GC_NewLine As String = Chr$(13) + Chr$(10) 
Dim GV_MBoxResult As Integer, GV_ArgStyle As Integer, GV_ArgText As String, _
    GV_ArgTitle As String
GV_ArgStyle = 1
GV_ArgTitle = "MBoxCMD"

' Parameter auswerten und aufbereiten
If Trim(Command(1)) <> "" Then
  GV_ArgText = Left(Trim(Command(1)), 250)
  If GV_ArgText <> "-?" And GV_ArgText <> "/?" Then
    GV_ArgText = MyReplace(GV_ArgText, "\n", GC_NewLine)
    If Trim(Command(2)) <> "" Then
      GV_ArgTitle = Left(Trim(Command(2)), 250)
    EndIf    
    If Trim(Command(3)) <> "" Then
      GV_ArgStyle = ValInt(Trim(Command(3))) And GC_ValidStyleMask
    EndIf
  Else
    MyHelpText
  EndIf
Else
  MyHelpText  
EndIf

' MessageBox anzeigen
GV_MBoxResult = MessageBox(NULL, GV_ArgText, GV_ArgTitle, GV_ArgStyle)

' Beenden und Ergebnis zurckliefern
End GV_MBoxResult



' ******************************************************************************
' *  Funktionen und Prozeduren
' ******************************************************************************
Sub MyHelpText()
  ' Gibt den Hilfetext aus und beendet das Programm dann
  Print "MBOXCMD 1.0 - written 2014 in FreeBASIC by Tobias Jacobi"
  Print ""
  Print "Shows a Messagebox from the command line and returns the result as Errorlevel."
  Print ""
  Print "USAGE:   MBOXCMD ""Text to be displayed"" [""Title""] [Style]"
  Print ""
  Print "EXAMPLE: MBOXCMD ""Line 1 of text ...\nLine 2 of text ..."" ""My title"" 68"
  Print "         ECHO %ERRORLEVEL%"
  Print ""
  Print "Style can be combined of (values must be added):"
  Print ""
  Print "      0 = OK         1 = OK/Cancel  4 = Yes/No        5 = Retry/Cancel"
  Print "     16 = Critical  32 = Question  48 = Exclamation  64 = Information"
  Print "    256 = Button 2 is default     512 = Button 3 is default"
  Print "   4096 = Window is system modal"
  Print ""
  Print "Returned Errorlevel (button pressed):"
  Print ""
  Print "      1 = OK         2 = Cancel     3 = Abort         4 = Retry"
  Print "      5 = Ignore     6 = Yes        7 = No"
  Print ""
  Print "This program is free of charge for private and commercial use, but without"
  Print "any warranty. You use it at your own risk."
  End 0
End Sub

Function MyReplace(ByVal PV_Original As String, _
                   ByVal PV_Displaced As String, _
                   ByVal PV_Replacement As String) As String
  ' Ersetzt im Text PV_Original die Vorkommen von PV_Displaced durch PV_Replacement 
  
  ' Lokale Variablen deklarieren und vorbelegen
  Dim LV_BigCounter As Integer, LV_LittleCounter As Integer, _
      LV_OriginalLen As Integer, LV_DisplacedLen As Integer, _
      LV_CounterDiff As Integer, LV_ResultText As String, _
      LV_TextBuffer As String
  LV_BigCounter = 1
  LV_LittleCounter = 1
  LV_ResultText = ""
  
  ' Lnge der bergebenen Texte merken
  LV_OriginalLen = Len(PV_Original)
  LV_DisplacedLen = Len(PV_Displaced)

  ' Original-Text abarbeiten, solange Ende nicht berschritten
  While LV_BigCounter <= LV_OriginalLen
    ' Puffer leeren
    LV_TextBuffer = ""
    ' Puffer mit der inneren Schleife fllen
    Do
      LV_TextBuffer += Mid(PV_Original, LV_LittleCounter, 1)
      LV_LittleCounter += 1
      LV_CounterDiff = LV_LittleCounter - LV_BigCounter
    Loop While LV_LittleCounter <= LV_OriginalLen And _
               Left(LV_TextBuffer, LV_CounterDiff) = _
                 Left(PV_Displaced, LV_CounterDiff) And _
               LV_CounterDiff < LV_DisplacedLen
    ' Ist der zu ersetzende Text im Puffer?
    If LV_TextBuffer = PV_Displaced Then
      ' Ja, also neuen Text anhngen
      LV_ResultText += PV_Replacement
    Else
      ' Nein, also Originaltext aus Puffer anhngen
      LV_ResultText += LV_TextBuffer
    EndIf
    ' uere Schleife entsprechend weitersetzen 
    LV_BigCounter = LV_LittleCounter
  Wend

  ' Ergebnis zurckliefern
  MyReplace = LV_ResultText
End Function
